summaryrefslogtreecommitdiff
path: root/src/mongo/db/ops/write_ops_retryability_test.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/ops/write_ops_retryability_test.cpp')
-rw-r--r--src/mongo/db/ops/write_ops_retryability_test.cpp10
1 files changed, 6 insertions, 4 deletions
diff --git a/src/mongo/db/ops/write_ops_retryability_test.cpp b/src/mongo/db/ops/write_ops_retryability_test.cpp
index 05c4828dae1..45a4305f012 100644
--- a/src/mongo/db/ops/write_ops_retryability_test.cpp
+++ b/src/mongo/db/ops/write_ops_retryability_test.cpp
@@ -58,7 +58,8 @@ repl::OplogEntry makeOplogEntry(repl::OpTime opTime,
BSONObj oField,
boost::optional<BSONObj> o2Field = boost::none,
boost::optional<repl::OpTime> preImageOpTime = boost::none,
- boost::optional<repl::OpTime> postImageOpTime = boost::none) {
+ boost::optional<repl::OpTime> postImageOpTime = boost::none,
+ boost::optional<bool> prepare = boost::none) {
return repl::OplogEntry(opTime, // optime
boost::none, // hash
opType, // opType
@@ -72,9 +73,10 @@ repl::OplogEntry makeOplogEntry(repl::OpTime opTime,
boost::none, // upsert
boost::none, // wall clock time
boost::none, // statement id
- boost::none, // optime of previous write within same transaction
- preImageOpTime, // pre-image optime
- postImageOpTime); // post-image optime
+ boost::none, // optime of previous write within same transaction
+ preImageOpTime, // pre-image optime
+ postImageOpTime, // post-image optime
+ prepare); // prepare
}
TEST_F(WriteOpsRetryability, ParseOplogEntryForUpdate) {